"""
Wrapper for the factura.com REST API
"""

DEBUG = False

FACTURACOM_API_KEY = ''
FACTURACOM_SECRET_KEY = ''

FACTURACOM_SANDBOX = 'http://devfactura.in'
FACTURACOM_PRODUCTION = 'https://factura.com'
FACTURACOM_NAMESPACE = '/api'
